OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Megjelenítő",
    "Simple file viewer with slideshow for media" : "Egyszerű fájlmegjelenítő diavetítéssel a médiafájlokhoz",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mutassa meg a kedvenc nyaralási fényképeit és videót mint a filmekben, mutassa meg a legfrissebb novellája részletét a Nextcloudban, válassza ki a legjobb GIF-képet a gyűjteményéből a kedvenc fájljainak közvetlen előnézetének, és a számos egyéb funkciónak köszönhetően.",
    "Error loading {name}" : "Hiba a(z) {name} betöltésekor",
    "Your browser does not support the video tag." : "A böngészője nem támogatja a video címkét.",
    "Open sidebar" : "Oldalsáv megnyitása",
    "View" : "Megtekintés",
    "Share" : "Megosztás"
},
"nplurals=2; plural=(n != 1);");
